@@ -138,11 +138,19 @@ double Board::GetMIN_SEPARATION()	// Minimum separation (in mil) between a pad o
 		if ( nodeIdA == BAD_NODEID ) continue;
 		const bool		bViaA	= pA->GetIsVia();
 		const bool		bPadA	= pA->GetHasPin();	assert( !(bViaA && bPadA) );
+		const bool		bWireA	= pA->GetHasWire();
 
 		int iA(0);
-		if ( bPadA )
+		if ( bWireA )
 		{
-			const Component& comp = m_compMgr.GetComponentById( pA->GetCompId() );
+			assert( bPadA );
+			iA = GetPAD_MIL();	// No custom pad size for wires
+		}
+		else if ( bPadA )
+		{
+			assert( pA->GetCompId() != BAD_COMPID );	// Non-wire part must use slot 0
+			const Component& comp	= m_compMgr.GetComponentById( pA->GetCompId() );
+			assert( comp.GetType() != COMP::INVALID );
 			iA = comp.GetCustomPads() ? comp.GetPadWidth() : GetPAD_MIL();
 		}
 		else if ( bViaA )	iA = GetVIAPAD_MIL();
@@ -162,13 +170,21 @@ double Board::GetMIN_SEPARATION()	// Minimum separation (in mil) between a pad o
 				const int&		nodeIdB	= pB->GetNodeId();
 				if ( nodeIdB == BAD_NODEID || nodeIdB == nodeIdA ) continue;
 
-				const bool bViaB = pB->GetIsVia();
-				const bool bPadB = pB->GetHasPin();	assert( !(bViaB && bPadB) );
+				const bool bViaB	= pB->GetIsVia();
+				const bool bPadB	= pB->GetHasPin();	assert( !(bViaB && bPadB) );
+				const bool bWireB	= pB->GetHasWire();
 
 				int iB(0);
-				if ( bPadB )
+				if ( bWireB )
 				{
-					const Component& comp = m_compMgr.GetComponentById( pB->GetCompId() );
+					assert( bPadB );
+					iB = GetPAD_MIL();	// No custom pad size for wires
+				}
+				else if ( bPadB )
+				{
+					assert( pB->GetCompId() != BAD_COMPID );	// Non-wire part must use slot 0
+					const Component& comp	= m_compMgr.GetComponentById( pB->GetCompId() );
+					assert( comp.GetType() != COMP::INVALID );
 					iB = comp.GetCustomPads() ? comp.GetPadWidth() : GetPAD_MIL();
 				}
 				else if ( bViaB )	iB = GetVIAPAD_MIL();
@@ -257,7 +273,9 @@ bool Board::SetNodeIdByUser(const int& lyr, const int& row, const int& col, cons
 
 		const size_t	pinIndex	= p->GetPinIndex();
 		const int&		compId		= p->GetCompId();
-		Component&		comp		= m_compMgr.GetComponentById(compId);
+		assert( compId != BAD_COMPID );
+		Component&		comp		= m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
 		assert( comp.GetType() != COMP::WIRE );	// Sanity check
 
 		if ( nodeId != BAD_NODEID && nodeId != comp.GetNodeId(pinIndex) ) return false;	// Can't set a bad origId
@@ -279,7 +297,9 @@ bool Board::SetNodeIdByUser(const int& lyr, const int& row, const int& col, cons
 		int		compId;
 		p->GetSlotInfo(p->GetUsedSlot(), pinIndex, compId);
 
-		const Component& comp	= m_compMgr.GetComponentById(compId);	assert( comp.GetType() == COMP::WIRE );
+		assert( compId != BAD_COMPID );
+		const Component& comp	= m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() == COMP::WIRE );	// Sanity check
 		const int		 origId	= comp.GetOrigId(lyr, pinIndex);
 
 		if ( nodeId == p->GetNodeId() && origId == nodeId && p->ReadFlagBits(USERSET) )
@@ -319,7 +339,8 @@ bool Board::SetNodeIdByUser(const int& lyr, const int& row, const int& col, cons
 
 					if ( pW == nullptr ) continue;
 
-					Component& comp = m_compMgr.GetComponentById(compId);
+					assert( compId != BAD_COMPID );
+					Component& comp = m_compMgr.GetComponentById( compId );
 					assert( comp.GetType() == COMP::WIRE );	// Sanity check
 					const size_t otherPinIndex = ( pinIndex == 0 ) ? 1 : 0;
 					if ( pL == p )	// If it's the point that was clicked on, then set both the nodeId and origId
@@ -338,7 +359,9 @@ bool Board::SetNodeIdByUser(const int& lyr, const int& row, const int& col, cons
 		{
 			const size_t	pinIndex	= p->GetPinIndex();
 			const int&		compId		= p->GetCompId();
-			Component&		comp		= m_compMgr.GetComponentById(compId);
+			assert( compId != BAD_COMPID );
+			Component&		comp		= m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
 			assert( bPaintPins && comp.GetType() != COMP::WIRE );	// Sanity check
 
 			// Need to do (RemoveComp/ SetNodeId/ AddComp) to ensure m_nodeInfoMgr is updated OK
@@ -368,7 +391,9 @@ void Board::FloodNodeId(const int& nodeId)
 			int compId;
 			p->GetSlotInfo(p->GetUsedSlot(), pinIndex, compId);
 
-			const Component& comp	= m_compMgr.GetComponentById(compId); assert( comp.GetType() == COMP::WIRE );
+			assert( compId != BAD_COMPID );
+			const Component& comp	= m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() == COMP::WIRE );	// Sanity check
 			const int		 origId	= comp.GetOrigId(lyr, pinIndex);
 
 			if ( origId != p->GetNodeId() || !p->ReadFlagBits(USERSET) ) continue; // Don't paint directly if it wasn't painted directly in the first place
@@ -493,17 +518,33 @@ void Board::SetSolder(const int& nodeId, const int& col, const bool& bVertical)
 
 			if ( pC->GetHasPin() )
 			{
-				if ( !pC->GetHasWire() && m_compMgr.GetComponentById(pC->GetCompId()).GetType() == COMP::PAD )
-					rowPads++;
-				else
+				if ( pC->GetHasWire() )	// Don't treat wire like pad
 					rowPins++;
+				else
+				{
+					assert( pC->GetCompId() != BAD_COMPID );
+					const Component& comp = m_compMgr.GetComponentById( pC->GetCompId() );
+					assert( comp.GetType() != COMP::INVALID );
+					if ( comp.GetType() == COMP::PAD )
+						rowPads++;
+					else
+						rowPins++;
+				}
 			}
 			if ( pR->GetHasPin() )
 			{
-				if ( !pR->GetHasWire() && m_compMgr.GetComponentById(pR->GetCompId()).GetType() == COMP::PAD )
-					rowPads++;
-				else
+				if ( pR->GetHasWire() )	// Don't treat wire like pad
 					rowPins++;
+				else
+				{
+					assert( pR->GetCompId() != BAD_COMPID );
+					const Component& comp = m_compMgr.GetComponentById( pR->GetCompId() );
+					assert( comp.GetType() != COMP::INVALID );
+					if ( comp.GetType() == COMP::PAD )
+						rowPads++;
+					else
+						rowPins++;
+				}
 			}
 			const bool bIsBetter =	( bestRow == -1 ) ||
 									( rowPads < bestRowPads ) ||
