@@ -387,7 +387,10 @@ public:
 	Component& GetUserComponent()	// The currently selected component
 	{
 		assert( m_groupMgr.GetNumUserComps() == 1 );	// Should only have one component selected
-		return m_compMgr.GetComponentById( m_groupMgr.GetUserCompId() );
+		assert( m_groupMgr.GetUserCompId() != BAD_COMPID );
+		Component& comp = m_compMgr.GetComponentById( m_groupMgr.GetUserCompId() );
+		assert( comp.GetType() != COMP::INVALID );
+		return comp;
 	}
 
 	// Methods to get objects at a grid location
@@ -441,6 +444,7 @@ public:
 	bool TakeOff(Component& comp);
 	void FloatAllComps();				// Float all components (i.e. take them off the board)
 	void PlaceFloaters();				// Try to place down all the floating components
+	void FixCorruption();
 
 	// GUI helpers for manipulating user-selected components
 	void SelectAllComps(bool bRestrictToRects);
@@ -610,6 +614,9 @@ public:
 			m_colorMgr.Load(inStream);		// Call Load() on color manager
 
 		RebuildAdjacencies();
+
+		if ( inStream.GetVersion() < VRT_VERSION_42 )
+			FixCorruption();
 	}
 
 	virtual void Save(DataStream& outStream) override
