@@ -32,6 +32,7 @@ void Board::DestroyComponent(Component& comp)	// Destroys a component on the boa
 int Board::CreateComponent(int iRow, int iCol, const COMP& eType, const Component* pComp)
 {
 	assert( pComp == nullptr || pComp->GetType() == eType );	// Sanity check
+	assert( eType != COMP::INVALID );
 
 	// Try and produce a simple unique Name for the new part if possible
 	char buffer[256] = {'\0'};
@@ -68,11 +69,14 @@ int Board::CreateComponent(int iRow, int iCol, const COMP& eType, const Componen
 int Board::AddComponent(int iRow, int iCol, const Component& tmp, bool bDoPlace)
 {
 	// Adds a new component to the board, and returns its compId
+	assert( tmp.GetType() != COMP::INVALID );
 
 	const int compId = m_compMgr.CreateComp(tmp, GetUsePCBshapes() );	// CompMgr makes a copy of tmp and returns its compId
 	if ( compId == INT_MAX ) return BAD_COMPID;		// Reached component limit !!!
 
-	Component& comp = m_compMgr.GetComponentById(compId);
+	assert( compId != BAD_COMPID );
+	Component& comp = m_compMgr.GetComponentById( compId );
+	assert( comp.GetType() != COMP::INVALID );
 
 	m_nodeInfoMgr.AddComp(comp);
 
@@ -593,7 +597,7 @@ bool Board::TakeOff(Component& comp)
 				// Wire-ends need special treatment, so just handle non-wire pins here
 				if ( !bWire )
 				{
-					for (int lyr = 0; lyr < GetLyrs(); lyr++)
+					for (int lyr = 0, lyrs = GetLyrs(); lyr < lyrs; lyr++)
 					{
 						Element* p = ( lyr == 0 ) ? pGrid : pGrid->GetNbr(NBR_X);
 						if ( p == nullptr ) continue;
@@ -652,6 +656,7 @@ bool Board::TakeOff(Component& comp)
 						if ( iPinIndex == BAD_PININDEX ) continue;
 						assert( tmpCompId != BAD_COMPID );
 						Component& comp = m_compMgr.GetComponentById( tmpCompId );
+						assert( comp.GetType() != COMP::INVALID );
 						comp.SetNodeId(iPinIndex, BAD_NODEID);
 					}
 					// ... and on the corresponding board points
@@ -665,7 +670,7 @@ bool Board::TakeOff(Component& comp)
 		if ( !pA->GetHasWire() )	// If we've taken off the last wire at the location
 		{
 			const bool bAllLyrs = false;
-			for (int lyr = 0; lyr < GetLyrs(); lyr++)
+			for (int lyr = 0, lyrs = GetLyrs(); lyr < lyrs; lyr++)
 			{
 				Element* p = ( lyr == 0 ) ? pA : pA->GetNbr(NBR_X);
 				if ( p == nullptr ) continue;
@@ -677,7 +682,7 @@ bool Board::TakeOff(Component& comp)
 		if ( !pB->GetHasWire() )	// If we've taken off the last wire at the location
 		{
 			const bool bAllLyrs = false;
-			for (int lyr = 0; lyr < GetLyrs(); lyr++)
+			for (int lyr = 0, lyrs = GetLyrs(); lyr < lyrs; lyr++)
 			{
 				Element* p = ( lyr == 0 ) ? pB : pB->GetNbr(NBR_X);
 				if ( p == nullptr ) continue;
@@ -752,13 +757,15 @@ void Board::SelectAllComps(bool bRestrictToRects)
 bool Board::ConfirmDestroyUserComps()	// returns false if user-group is empty or has only wires and markers
 {
 	std::list<int> userCompIds;
-	m_groupMgr.GetGroupCompIds(USER_GROUPID, userCompIds);
+	m_groupMgr.GetUserCompIds(userCompIds);
 	for (const auto& compId : userCompIds)
 	{
-		switch( m_compMgr.GetComponentById(compId).GetType() )
+		assert( compId != BAD_COMPID );
+		switch( m_compMgr.GetComponentById( compId ).GetType() )
 		{
 			case COMP::WIRE:
 			case COMP::MARK:	continue;
+			case COMP::INVALID:	assert(0);
 			default:			return true;
 		}
 	}
@@ -769,8 +776,14 @@ void Board::DestroyUserComps()	// Destroy components in the user-group
 {
 	WipeAutoSetPoints();
 	std::list<int> userCompIds;
-	m_groupMgr.GetGroupCompIds(USER_GROUPID, userCompIds);
-	for (const auto& compId : userCompIds) DestroyComponent( m_compMgr.GetComponentById(compId) );
+	m_groupMgr.GetUserCompIds(userCompIds);
+	for (const auto& compId : userCompIds)
+	{
+		assert( compId != BAD_COMPID );
+		Component& comp = m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
+		DestroyComponent( comp );
+	}
 	assert( m_groupMgr.GetNumUserComps() == 0 );	// User group should be empty now
 	SetCurrentCompId(BAD_COMPID);
 	PlaceFloaters();		// See if we can now place floating components down
@@ -884,7 +897,7 @@ void Board::ChangeTypeUserComp(const COMP& eType)
 void Board::CopyUserComps()	// Make a blank copy of the user-group components and float them
 {
 	std::list<int> userCompIds;
-	m_groupMgr.GetGroupCompIds(USER_GROUPID, userCompIds);
+	m_groupMgr.GetUserCompIds(userCompIds);
 
 	CopyComps(userCompIds);
 }
@@ -895,7 +908,7 @@ bool Board::MoveUserComps(const int& deltaRow, const int& deltaCol)	// Move user
 	if ( GetDisableMove() ) return false;
 
 	std::list<int> userCompIds;
-	m_groupMgr.GetGroupCompIds(USER_GROUPID, userCompIds);
+	m_groupMgr.GetUserCompIds(userCompIds);
 
 	return MoveComps(userCompIds, deltaRow, deltaCol);
 }
@@ -903,7 +916,7 @@ bool Board::MoveUserComps(const int& deltaRow, const int& deltaCol)	// Move user
 void Board::RotateUserComps(const bool& bCW)	// Rotate the selected components
 {
 	std::list<int> userCompIds;
-	m_groupMgr.GetGroupCompIds(USER_GROUPID, userCompIds);
+	m_groupMgr.GetUserCompIds(userCompIds);
 
 	RotateComps(userCompIds, bCW);
 }
@@ -917,7 +930,9 @@ void Board::CopyComps(const std::list<int>& compIds)	// Make a blank copy of the
 	if ( bMakeNewGroup && newGroupId == INT_MAX ) return;	// Fail if we've reached the max allowed groupId
 	for (auto& compId : compIds)
 	{
+		assert( compId != BAD_COMPID );
 		const Component&	comp		= m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
 		const int			newCompId	= CreateComponent(-1, -1, comp.GetType(), &comp);	// Create blank copy of the component and get its compId
 		if ( newCompId == BAD_COMPID ) break;	// Reached component limit
 		if ( bMakeNewGroup ) m_groupMgr.Add(newGroupId, newCompId);
@@ -978,7 +993,9 @@ bool Board::MoveComps(const std::list<int>& compIds, const int& deltaRow, const
 	// Take off all comps, and finally the trax comp. Move them but keep them floating.
 	for (auto& compId : compIds)
 	{
+		assert( compId != BAD_COMPID );
 		Component& comp = m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
 		int newRow = comp.GetRow() + deltaRow;
 		int newCol = comp.GetCol() + deltaCol;
 		MakeToroid(newRow, newCol);	// Make co-ordinates wrap around at grid edges
@@ -1004,7 +1021,12 @@ bool Board::MoveComps(const std::list<int>& compIds, const int& deltaRow, const
 	if ( trax.GetSize() == 0 || trax.GetIsPlaced() )
 	{
 		for (auto& compId : compIds)
-			PutDown( m_compMgr.GetComponentById( compId ) );
+		{
+			assert( compId != BAD_COMPID );
+			Component& comp = m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
+			PutDown(comp);
+		}
 		PlaceFloaters();	// See if we can now place floating components down
 	}
 	return bPanned;
@@ -1051,7 +1073,9 @@ void Board::RotateComps(const std::list<int>& compIds, const bool& bCW)	// Rotat
 	// Take off all comps, and finally the trax comp. Move and rotate them but keep them floating.
 	for (auto& compId : compIds)
 	{
+		assert( compId != BAD_COMPID );
 		Component& comp	= m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
 		TakeOff(comp);
 
 		int newRow(newCentreRow), newCol(newCentreCol);	// Start with the new group centre
@@ -1098,17 +1122,68 @@ void Board::RotateComps(const std::list<int>& compIds, const bool& bCW)	// Rotat
 	if ( trax.GetSize() == 0 || trax.GetIsPlaced() )
 	{
 		for (auto& compId : compIds)
-			PutDown( m_compMgr.GetComponentById( compId ) );
+		{
+			assert( compId != BAD_COMPID );
+			Component& comp = m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
+			PutDown(comp);
+		}
 		PlaceFloaters();	// See if we can now place floating components down
 	}
 }
 
+void Board::FixCorruption()
+{
+	// The following should not really be necessary, but if we have a corrupt state
+	// we should at least allow the user to try fix the board so it can continue to be used.
+
+	// Destroy any components that have an invalid component type
+	std::set<int> badCompIds;
+	m_compMgr.GetBadCompIds(badCompIds);
+
+	for (auto& compId : badCompIds)
+	{
+		assert( compId != BAD_COMPID );
+		Component& comp = m_compMgr.GetComponentById( compId );
+		DestroyComponent(comp);
+	}
+
+	FloatAllComps();	// Float all components
+
+	// Ensure there are no component related effects on the board elements
+	for (int i = 0, iSize = GetSize(); i < iSize; i++)
+	{
+		Element* p = GetAt(i);
+		const bool bOK = p->GetCompId()		== BAD_COMPID	&&
+						 p->GetCompId2()	== BAD_COMPID	&&
+						 p->GetPinIndex()	== BAD_PININDEX	&&
+						 p->GetPinIndex2()	== BAD_PININDEX &&
+						 p->GetSurface()	== SURFACE_FREE &&
+						 p->GetHoleUse()	== HOLE_FREE	&&
+						 p->GetIsMark()		== false;
+		if ( !bOK )
+		{
+			p->SetCompId(BAD_COMPID);
+			p->SetCompId2(BAD_COMPID);
+			p->SetPinIndex(BAD_PININDEX);
+			p->SetPinIndex2(BAD_PININDEX);
+			p->SetSurface(SURFACE_FREE);
+			p->SetHoleUse(HOLE_FREE);
+			p->SetIsMark(false);
+		}
+	}
+
+	PlaceFloaters();	// Unfloat components
+}
+
 Rect Board::GetFootprintBounds(const std::list<int>& compIds)
 {
 	Rect bounding;
 	for (auto& compId : compIds)
 	{
+		assert( compId != BAD_COMPID );
 		const Component& comp	= m_compMgr.GetComponentById( compId );
+		assert( comp.GetType() != COMP::INVALID );
 		bounding |= comp.GetFootprintRect();
 	}
 	const Component& trax = m_compMgr.GetTrax();
