@@ -172,6 +172,7 @@ bool Board::ImportTango(const TemplateManager& templateMgr, const std::string& f
 					}
 					else
 					{
+						assert( eType != COMP::INVALID );
 						nodeList.resize(numPins, BAD_NODEID);
 						Component tmp(nameStr, valueStr, eType, nodeList);
 						if ( nLength > 0 )
@@ -224,7 +225,11 @@ bool Board::ImportTango(const TemplateManager& templateMgr, const std::string& f
 
 					if ( bOK )
 					{
-						bOK = iPinIndex < m_compMgr.GetComponentById(compId).GetNumPins();
+						assert( compId != BAD_COMPID );
+						const Component& comp = m_compMgr.GetComponentById( compId );
+						assert( comp.GetType() != COMP::INVALID );
+
+						bOK = iPinIndex < comp.GetNumPins();
 						if ( !bOK ) errorStr = "Net section: " + netStr + "\nLine has invalid pin number: " + str;
 					}
 					if ( bOK )
@@ -245,7 +250,13 @@ bool Board::ImportTango(const TemplateManager& templateMgr, const std::string& f
 	// Break the SIPS representing off-board parts into PADs
 	if ( bOK )
 		for (const auto& nameStr : offBoard)
-			BreakComponentIntoPads( m_compMgr.GetComponentById( m_compMgr.GetComponentIdFromName(nameStr) ) );
+		{
+			const int	compId	= m_compMgr.GetComponentIdFromName( nameStr );
+			assert( compId != BAD_COMPID );
+			Component&	comp	= m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
+			BreakComponentIntoPads(comp);
+		}
 
 	return bOK;
 }
@@ -316,7 +327,7 @@ bool Board::ImportOrcad(const TemplateManager& templateMgr, const std::string& f
 			std::vector<std::string> strList;
 
 			StringHelper::GetSubStrings(str, strList);	// Break str into space separated list
-			const size_t numSubStrings =  strList.size();
+			const size_t numSubStrings = strList.size();
 
 			if ( numSubStrings < 4 || numSubStrings > 5 )
 			{
@@ -430,6 +441,7 @@ bool Board::ImportOrcad(const TemplateManager& templateMgr, const std::string& f
 			}
 			else
 			{
+				assert( eType != COMP::INVALID );
 				nodeList.resize(numPins, BAD_NODEID);
 				Component tmp(nameStr, valueStr, eType, nodeList);
 				if ( nLength > 0 )
@@ -492,7 +504,7 @@ bool Board::ImportOrcad(const TemplateManager& templateMgr, const std::string& f
 
 			// Paint the component pin using SetNodeIdByUser
 			const size_t	iPinIndex	= atoi(pinStr.c_str()) - 1;
-			const int		compId		= m_compMgr.GetComponentIdFromName(nameStr);
+			const int		compId		= m_compMgr.GetComponentIdFromName( nameStr );
 
 			bOK = compId != BAD_COMPID;
 			if ( !bOK )
@@ -500,7 +512,12 @@ bool Board::ImportOrcad(const TemplateManager& templateMgr, const std::string& f
 				errorStr = "Internal error: VeroRoute lost the component ID";
 				break;
 			}
-			bOK = iPinIndex < m_compMgr.GetComponentById(compId).GetNumPins();
+
+			assert( compId != BAD_COMPID );
+			const Component& comp = m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
+
+			bOK = iPinIndex < comp.GetNumPins();
 			if ( !bOK )
 			{
 				errorStr = "Part: " + nameStr + "\nLine has invalid pin number: " + str;
@@ -522,7 +539,13 @@ bool Board::ImportOrcad(const TemplateManager& templateMgr, const std::string& f
 	// Break the SIPS representing off-board parts into PADs
 	if ( bOK )
 		for (const auto& nameStr : offBoard)
-			BreakComponentIntoPads( m_compMgr.GetComponentById( m_compMgr.GetComponentIdFromName(nameStr) ) );
+		{
+			const int	compId	= m_compMgr.GetComponentIdFromName( nameStr );
+			assert( compId != BAD_COMPID );
+			Component&	comp	= m_compMgr.GetComponentById( compId );
+			assert( comp.GetType() != COMP::INVALID );
+			BreakComponentIntoPads(comp);
+		}
 
 	return bOK;
 }
@@ -534,8 +557,7 @@ bool Board::BreakComponentIntoPads(Component& comp)
 	if ( eType == COMP::MARK || eType == COMP::PAD || eType == COMP::WIRE ) return false;	// Not real components
 	if ( !comp.GetIsPlaced() ) return false;	// Can't break a floating component
 
-	std::vector<int> nodeList;	// Re-used for each new pad
-	nodeList.resize(1, BAD_NODEID);
+	std::vector<int> nodeList = { BAD_NODEID };	// Re-used for each new pad
 
 	const size_t numPins = comp.GetNumPins();
 	for (size_t iPinIndex = 0; iPinIndex < numPins; iPinIndex++)	// Loop component pins
