@@ -96,7 +96,8 @@ void Component::SetDefaultPinFlags()
 		case COMP::TRIM_3362Z:
 		case COMP::CRYSTAL:	assert( GetPinFlags() == iCustomFlag );	return SetPinFlags(iCustomFlag);
 		case COMP::CUSTOM:
-		case COMP::TRACKS:		return;
+		case COMP::TRACKS:
+		case COMP::INVALID:		return;
 		default:	assert(0);	return;	// Unhandled eType
 	}
 }
@@ -116,18 +117,24 @@ void Component::SetDefaultShapes(const bool& bUsePCBshapes)
 											AddOne( Shape(SHAPE::LINE,		true, false,	-0.21,  0.21,  0.21, -0.21) );	break;
 		case COMP::PAD:						AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-0.45,  0.45, -0.45,  0.45) );	break;
 		case COMP::LED:						AddTwo( Shape(SHAPE::CHORD,		true, true,		-0.75,  0.75, -0.75,  0.75, 30, -30) );break;
-		case COMP::CAP_ELECTRO_200:			AddOne( Shape(SHAPE::LINE,		true, false,	 0.77,  0.77, -0.64,  0.64) );
 		case COMP::CAP_ELECTRO_200_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.00,  1.00, -1.00,  1.00) );	break;
-		case COMP::CAP_ELECTRO_250:			AddOne( Shape(SHAPE::LINE,		true, false,	 0.96,  0.96, -0.80,  0.80) );
 		case COMP::CAP_ELECTRO_250_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.25,  1.25, -1.25,  1.25) );	break;
-		case COMP::CAP_ELECTRO_300:			AddOne( Shape(SHAPE::LINE,		true, false,	 1.15,  1.15, -0.96,  0.96) );
 		case COMP::CAP_ELECTRO_300_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.50,  1.50, -1.50,  1.50) );	break;
-		case COMP::CAP_ELECTRO_400:			AddOne( Shape(SHAPE::LINE,		true, false,	 1.53,  1.53, -1.29,  1.29) );
 		case COMP::CAP_ELECTRO_400_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-2.00,  2.00, -2.00,  2.00) );	break;
-		case COMP::CAP_ELECTRO_500:			AddOne( Shape(SHAPE::LINE,		true, false,	 1.92,  1.92, -1.61,  1.61) );
 		case COMP::CAP_ELECTRO_500_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-2.50,  2.50, -2.50,  2.50) );	break;
-		case COMP::CAP_ELECTRO_600:			AddOne( Shape(SHAPE::LINE,		true, false,	 2.30,  2.30, -1.93,  1.93) );
 		case COMP::CAP_ELECTRO_600_NP:		AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-3.00,  3.00, -3.00,  3.00) );	break;
+		case COMP::CAP_ELECTRO_200:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.00,  1.00, -1.00,  1.00) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 0.77,  0.77, -0.64,  0.64) );	break;
+		case COMP::CAP_ELECTRO_250:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.25,  1.25, -1.25,  1.25) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 0.96,  0.96, -0.80,  0.80) );	break;
+		case COMP::CAP_ELECTRO_300:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-1.50,  1.50, -1.50,  1.50) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 1.15,  1.15, -0.96,  0.96) );	break;
+		case COMP::CAP_ELECTRO_400:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-2.00,  2.00, -2.00,  2.00) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 1.53,  1.53, -1.29,  1.29) );	break;
+		case COMP::CAP_ELECTRO_500:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-2.50,  2.50, -2.50,  2.50) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 1.92,  1.92, -1.61,  1.61) );	break;
+		case COMP::CAP_ELECTRO_600:			AddTwo( Shape(SHAPE::ELLIPSE,	true, true,		-3.00,  3.00, -3.00,  3.00) );
+											AddOne( Shape(SHAPE::LINE,		true, false,	 2.30,  2.30, -1.93,  1.93) );	break;
 		case COMP::TRIM_VERT:				AddTwo( Shape(SHAPE::RECT,		true, true,		-1.50,  1.50, -0.50,  0.50) );	break;
 		case COMP::TRIM_VERT_OFFSET:		AddTwo( Shape(SHAPE::RECT,		true, true,		-1.50,  1.50, -0.75,  0.75) );	break;
 		case COMP::TRIM_VERT_OFFSET_WIDE:	AddTwo( Shape(SHAPE::RECT,		true, true,		-1.50,  1.50, -1.00,  1.00) );	break;
@@ -296,6 +303,7 @@ void Component::SetDefaultShapes(const bool& bUsePCBshapes)
 			}
 			break;
 		}
+		case COMP::INVALID:	break;
 		default:	assert(0);	// Unhandled eType
 	}
 	std::sort(m_shapes.begin(), m_shapes.end());	// Sort shapes so fills are rendered before lines
@@ -379,6 +387,7 @@ void Component::SetDefaultColor()
 		case COMP::STRIP_100:				return SetFillColor(MyRGB(0xFFFFDF));
 		case COMP::BLOCK_100:				return SetFillColor(MyRGB(0xFFFFDF));
 		case COMP::BLOCK_200:				return SetFillColor(MyRGB(0xFFFFDF));
+		case COMP::INVALID:					return;
 		default:	assert(0);	// Unhandled eType
 	}
 }
