@@ -245,4 +245,15 @@ static const char* szVEROROUTE_VERSION =
 			// New feature: Allow user to specify a color for any NodeID.
 			// Improvement: Show info on Bad/Floating nodes in a single list.
 			// For consistency between view types, draw hashed lines for broken connections in red instead of yellow.
-  "1.96";	// New feature: In Color mode, color each wire according to its NodeId.
+//"1.96";	// New feature: In Color mode, color each wire according to its NodeId.
+//"1.97";	// Bug fix: In Color mode, diagonal track portions were drawn too long if using custom track color.
+			// Disabled code for drawing extra thermal relief tags (so a filled PCB will be easier to solder).
+//"1.98";	// Put in extra checks to stop potential crashes arising from a corrupted layout.
+			// Added file menu option to fix a corrupted layout.
+//"1.99";	// Code changes to help prevent layout from becoming corrupted.
+  "2.00";	// Bug fix: Poor-man's 2-layer Gerber export was not handling crossing wires.
+			// Bug fix: Isolated nodes were rendered to Gerber with pad-width instead of track-width.
+			// Bug fix: Isolated nodes were rendered to top layer for poor-man's 2-layer Gerber export.
+			// Improvement: Allow TAB to change focus of dialog controls.
+			// Improvement: Reworked some icons that did not work well with dark themes.
+			// Removed menu item to fix corruption.  Old corrupted VRTS are now auto-fixed on load.
