@@ -514,6 +514,8 @@ private:
 	QPixmap**	m_ppPixmapVia	= nullptr;	// A via in the host element
 	QPixmap**	m_ppPixmapDiag	= nullptr;	// For filling small diagonal gaps not covered by blob pixmaps
 	QPixmap**	m_ppPixmapBlob	= nullptr;	// A composite shape with all the host element connections
+	QPixmap*	m_pPixmapDiagLT	= nullptr;	// Used instead of m_ppPixmapDiag for custom colors
+	QPixmap*	m_pPixmapDiagRT	= nullptr;	// Used instead of m_ppPixmapDiag for custom colors
 	int			m_radPixmapPad	= 0;		// Half pixmap width ...
 	int			m_radPixmapVia	= 0;		// ...
 	int			m_radPixmapDiag	= 0;		// ...
