@@ -31,6 +31,8 @@ void MainWindow::DestroyPixmapCache()
 	delete[] m_ppPixmapVia;		m_ppPixmapVia	= nullptr;
 	delete[] m_ppPixmapDiag;	m_ppPixmapDiag	= nullptr;
 	delete[] m_ppPixmapBlob;	m_ppPixmapBlob	= nullptr;
+	delete   m_pPixmapDiagLT;	m_pPixmapDiagLT = nullptr;
+	delete   m_pPixmapDiagRT;	m_pPixmapDiagRT = nullptr;
 }
 
 void MainWindow::CreatePixmapCache(const GuiControl& guiCtrl, ColorManager& colorMgr)
@@ -54,6 +56,11 @@ void MainWindow::CreatePixmapCache(const GuiControl& guiCtrl, ColorManager& colo
 	m_ppPixmapDiag	= new QPixmap*[2 * NUM_PIXMAP_COLORS];
 	m_ppPixmapBlob	= new QPixmap*[256];
 
+	m_pPixmapDiagLT = new QPixmap(2*m_radPixmapDiag, 2*m_radPixmapDiag);
+	m_pPixmapDiagLT->fill(Qt::transparent);
+	m_pPixmapDiagRT	= new QPixmap(2*m_radPixmapDiag, 2*m_radPixmapDiag);
+	m_pPixmapDiagRT->fill(Qt::transparent);
+
 	QPainter painter;
 	for (int i = 0; i < NUM_PIXMAP_COLORS; i++)
 	{
@@ -360,17 +367,23 @@ void MainWindow::PaintBlob(const GuiControl& guiCtrl, QPainter& painter, const Q
 	brush.setColor(color);
 
 	// Draw
-	if ( N == 0 )	// Isolated node
+	if ( N == 0 )	// Isolated node (no longer drawn as pad)
 	{
 		if ( m_bWriteGerber )
 		{
 			assert( polygon.size() == 1 );
-			m_gWriter.GetStream(GFILE::GTL).AddTrack(polygon, bGap ? GPEN::PAD_GAP : GPEN::PAD);	// Top    copper layer
-			m_gWriter.GetStream(GFILE::GBL).AddTrack(polygon, bGap ? GPEN::PAD_GAP : GPEN::PAD);	// Bottom copper layer
+
+			auto& osT = m_gWriter.GetStream(GFILE::GTL);	// Top    copper layer
+			auto& osB = m_gWriter.GetStream(GFILE::GBL);	// Bottom copper layer
+			const GPEN ePen		= bGap ? GPEN::TRK_GAP : GPEN::TRK;
+
+			if ( m_board.GetLyrs() > 1 )
+				osT.AddTrack(polygon, ePen);
+			osB.AddTrack(polygon, ePen);
 		}
 		else
 		{
-			pen.setWidth(trackWidth);	// No longer drawn as a pad
+			pen.setWidth(trackWidth);
 			painter.setPen(pen);
 			painter.drawPoint(pC);
 		}
@@ -669,8 +682,9 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 	const bool		 bPCB			= trackMode == TRACKMODE::PCB;
 	const bool		 bMonoPCB		= bMono || bPCB;
 	const bool		 bGroundFill	= !bVero && bMonoPCB && board.GetGroundFill();
-	const bool		 bPixmapCache	= !bVero && !bPCB && !bGroundFill && !m_bWritePDF;
-	const bool		 bDirect		= !bVero && !bPixmapCache && !bGroundFill;
+	const bool		 bPixmapCache	= !bVero && !bPCB && !bGroundFill && !m_bWritePDF;	// true ==> Faster rendering (Mono/Color modes)
+	const bool		 bDirect		= !bVero && !bPixmapCache && !bGroundFill;			// true ==> Draw track "blobs" and pads directly (PDF/Gerber)
+	const bool		 bExtraTags		= false;											// true ==> Add extra thermal relief tags
 	const int&		 layer			= board.GetCurrentLayer();
 	const int&		 groundNodeId	= ( layer == 0 ) ? board.GetGroundNodeId0() :  board.GetGroundNodeId1();
 	const bool		 bWiresAsTracks	= m_bWriteGerber && m_bTwoLayerGerber && board.GetLyrs() == 1;	// true ==> Convert wires to tracks on the top layer
@@ -699,7 +713,7 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 	std::vector<const Component*> sortedComps;
 	if ( compMode != COMPSMODE::OFF || bMonoPCB )
 	{
-		compMgr.CalculateWireShifts();			// Work out shifts for overlaid wires
+		compMgr.CalculateWireInfo();			// Work out shifts for overlaid wires and flag crossing wires
 		compMgr.GetSortedComps(sortedComps);	// Sorted so floating and "plug" components get rendered last
 	}
 
@@ -714,7 +728,7 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 	{
 		pdfWriter = new QPdfWriter(m_pdfFileName);
 		pdfWriter->setCreator("VeroRoute");
-		pdfWriter->setPageSize(QPagedPaintDevice::A4);
+		pdfWriter->setPageSize(QPageSize(QPageSize::A4));
 		pdfWriter->setPageOrientation(QPageLayout::Landscape);
 		pdfWriter->setResolution(1200);
 		painter.begin(pdfWriter);	// Paint to PDF file
@@ -858,8 +872,10 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 				int iPadWidthMIL(0), iHoleWidthMIL(0);	// 0 ==> Not a custom value
 				if ( bPad && !bWire )
 				{
-					const int		 compId	= pC->GetCompId(); assert(compId != BAD_COMPID);
-					const Component& comp	= compMgr.GetComponentById(compId);
+					const int		 compId	= pC->GetCompId();
+					assert( compId != BAD_COMPID );
+					const Component& comp	= compMgr.GetComponentById( compId );
+					assert( comp.GetType() != COMP::INVALID );
 					bCustom = comp.GetCustomPads();
 					if ( bCustom )
 					{
@@ -979,15 +995,28 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 						// Read flags for LT and RT so we can fill diagonal gaps produced on previous iLoop
 						const bool bUsedLT = ReadCodeBit(NBR_LT, iPerimeterCode);
 						const bool bUsedRT = ReadCodeBit(NBR_RT, iPerimeterCode);
-						if ( bCustomColor )
+						if ( bUsedLT || bUsedRT )
 						{
-							if ( bUsedLT ) PaintDiag(board, painter, color, QPointF(L,T), true);
-							if ( bUsedRT ) PaintDiag(board, painter, color, QPointF(R,T), false);
-						}
-						else
-						{
-							if ( bUsedLT ) painter.drawPixmap(L-m_radPixmapDiag, T-m_radPixmapDiag, *(m_ppPixmapDiag[iEffColorId]));
-							if ( bUsedRT ) painter.drawPixmap(R-m_radPixmapDiag, T-m_radPixmapDiag, *(m_ppPixmapDiag[iEffColorId + NUM_PIXMAP_COLORS]));
+							QPixmap* pLT = bCustomColor ? m_pPixmapDiagLT : m_ppPixmapDiag[iEffColorId];
+							QPixmap* pRT = bCustomColor ? m_pPixmapDiagRT : m_ppPixmapDiag[iEffColorId + NUM_PIXMAP_COLORS];
+							if ( bCustomColor )
+							{
+								QPainter painterTmp;
+								if ( bUsedLT )
+								{
+									painterTmp.begin(m_pPixmapDiagLT);
+									PaintDiag(board, painterTmp, color, QPointF(m_radPixmapDiag, m_radPixmapDiag), true);
+									painterTmp.end();
+								}
+								if ( bUsedRT )
+								{
+									painterTmp.begin(m_pPixmapDiagRT);
+									PaintDiag(board, painterTmp, color, QPointF(m_radPixmapDiag, m_radPixmapDiag), false);
+									painterTmp.end();
+								}
+							}
+							if ( bUsedLT ) painter.drawPixmap(L-m_radPixmapDiag, T-m_radPixmapDiag, *pLT);
+							if ( bUsedRT ) painter.drawPixmap(R-m_radPixmapDiag, T-m_radPixmapDiag, *pRT);
 						}
 					}
 				}
@@ -1005,7 +1034,7 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 						PaintBlob(board, painter, color, pCentre, iPerimeterCode);							// Draw track blob
 						if ( bVia ) PaintVia(board, painter, color, pCentre);								// Draw via same color as track
 						if ( bPad ) PaintPad(board, painter, color, pCentre, iPadWidthMIL, iHoleWidthMIL);	// Draw pad same color as track
-						if ( bPad && nodeId == groundNodeId && nodeId != BAD_NODEID )						// Draw thermal relief tags
+						if ( bExtraTags && bPad && nodeId == groundNodeId && nodeId != BAD_NODEID )			// Draw extra thermal relief tags
 						{
 							int iCode(iPerimeterCode);		// Take a copy of the perimeter code
 							for (int iDiag = 0, iDiagMax = ( bDiagsOK ) ? 2 : 1; iDiag < iDiagMax; iDiag++)	// First pass ==> Non-diagonal nbrs.  Second pass diagonal nbrs
@@ -1048,7 +1077,7 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 				{
 					const Component& comp = *pComp;
 					if ( comp.GetType() != COMP::WIRE || !comp.GetIsPlaced() ) continue;	// Only want placed wires
-					if ( compMgr.GetWireShift( &comp ) != 0 ) continue;	//TODO Probably not a good enough check since wires may cross yet have no shift
+					if ( !compMgr.GetWireCanBeTrack(&comp) ) continue;
 
 					QPolygonF polygon;
 					GetXY(board, comp.GetRow(), comp.GetCol(), X, Y);
@@ -1190,7 +1219,7 @@ void MainWindow::PaintBoard()	// The paint method in "circuit layout mode"
 			const bool		 bPlaced		= comp.GetIsPlaced();
 			if ( bPCB && bMark )	continue;	// Don't show markers in PCB mode
 			if ( m_bWriteGerber && !bPlaced ) continue;	// Don't write floating components to Gerber
-			if ( bWiresAsTracks && bWire && compMgr.GetWireShift(&comp) == 0 ) continue;	//TODO Probably not a good enough check since wires may cross yet have no shift
+			if ( bWiresAsTracks && bWire && compMgr.GetWireCanBeTrack(&comp) ) continue;
 			const bool 		 bFound			= compMgr.GetFound( comp.GetId() );
 			const bool		 bPinLabels		= !bMonoPCB && (comp.GetPinFlags() & PIN_LABELS) > 0 && board.GetShowPinLabels();
 			const bool		 bRectPins		= !bMonoPCB && (comp.GetPinFlags() & PIN_RECT) > 0;
